%global pkgconf_libdirs %{_libdir}/pkgconfig:%{_datadir}/pkgconfig

Summary:        Package compiler and linker metadata toolkit
Name:           pkgconf
Version:        1.9.5
Release:        4%{?dist}
License:        ISC
URL:            http://pkgconf.org/
Source0:        https://distfiles.dereferenced.org/%{name}/%{name}-%{version}.tar.xz
Source1:        platform-pkg-config.in
Source2:        pkg-config.in

BuildRequires:  gcc, make, autoconf, automake, libtool
BuildRequires:  kyua, atf-tests

Requires:       libpkgconf = %{version}-%{release}
Provides:       pkgconfig(pkgconf) = %{version}

%description
pkgconf is a program which helps to configure compiler and linker flags for
development libraries. It is similar to pkg-config from freedesktop.org.

%package -n libpkgconf
Summary:        Backend library for pkgconf

%description -n libpkgconf
This package provides libraries for applications to use the functionality
of pkgconf.

%package -n libpkgconf-devel
Summary:        Development files for libpkgconf
Requires:       libpkgconf = %{version}-%{release}

%description -n libpkgconf-devel
This package provides files necessary for developing applications
to use functionality provided by pkgconf.

%package m4
Summary:        m4 macros for pkgconf
License:        GPLv2+ with exceptions
BuildArch:      noarch

%description m4
This package includes m4 macros used to support PKG_CHECK_MODULES
when using pkgconf with autotools.

%package pkg-config
Summary:        pkgconf shim to provide /usr/bin/pkg-config
Provides:       pkgconfig
Provides:       pkgconfig(pkg-config) = %{version}
Provides:       pkg-config

Requires:       pkgconf = %{version}-%{release}
Requires:       pkgconf-m4 = %{version}-%{release}

%description pkg-config
This package provides the shim links for pkgconf to be automatically
used in place of pkgconfig. This ensures that pkgconf is used as
the system provider of pkg-config.

%package -n bomtool
Summary:        Simple SBOM generator using pc(5) files
Requires:       libpkgconf = %{version}-%{release}

%description -n bomtool
bomtool is a program which helps generate a Software Bill of Materials manifest
using data from installed .pc files.

%prep
%autosetup -p1



%build
autoreconf -fiv
%configure --disable-static \
           --with-pkg-config-dir=%{pkgconf_libdirs} \
           --with-system-includedir=%{_includedir} \
           --with-system-libdir=%{_libdir}

%make_build V=1



%check
make check



%install
%make_install

find %{buildroot} -name '*.la' -print -delete

mkdir -p %{buildroot}%{_sysconfdir}/pkgconfig/personality.d
mkdir -p %{buildroot}%{_datadir}/pkgconfig/personality.d

# pkgconf rpm macros
mkdir -p %{buildroot}%{_rpmmacrodir}/

cat > %{buildroot}%{_rpmmacrodir}/macros.pkgconf <<EOM
%%pkgconfig_personalitydir %{_datadir}/pkgconfig/personality.d
EOM


install -pm 0755 %{SOURCE1} %{buildroot}%{_bindir}/%{_target_platform}-pkg-config

sed -e "s|@TARGET_PLATFORM@|%{_target_platform}|" \
    -e "s|@PKGCONF_LIBDIRS_LOCAL@|/usr/local/%{_lib}/pkgconfig:/usr/local/share/pkgconfig:%{pkgconf_libdirs}|" \
    -e "s|@PKGCONF_LIBDIRS@|%{pkgconf_libdirs}|" \
    -e "s|@PKGCONF_SYSLIBDIR@|%{_libdir}|" \
    -e "s|@PKGCONF_SYSINCDIR@|%{_includedir}|" \
    -i %{buildroot}%{_bindir}/%{_target_platform}-pkg-config

install -pm 0755 %{SOURCE2} %{buildroot}%{_bindir}/pkg-config

sed -e "s|@PKGCONF_BINDIR@|%{_bindir}|" -i %{buildroot}%{_bindir}/pkg-config

echo ".so man1/pkgconf.1" > %{buildroot}%{_mandir}/man1/pkg-config.1

mkdir -p %{buildroot}%{_libdir}/pkgconfig
mkdir -p %{buildroot}%{_datadir}/pkgconfig



%post -n libpkgconf -p /sbin/ldconfig
%postun -n libpkgconf -p /sbin/ldconfig

%files
%license COPYING
%doc README.md AUTHORS NEWS
%{_bindir}/pkgconf
%{_mandir}/man1/pkgconf.1*
%{_mandir}/man5/pc.5*
%{_mandir}/man5/pkgconf-personality.5*
%{_rpmmacrodir}/macros.pkgconf
%dir %{_sysconfdir}/pkgconfig
%dir %{_sysconfdir}/pkgconfig/personality.d
%dir %{_datadir}/pkgconfig/personality.d

%files -n libpkgconf
%license COPYING
%{_libdir}/libpkgconf*.so.*

%files -n libpkgconf-devel
%{_libdir}/libpkgconf*.so
%{_includedir}/pkgconf/
%{_libdir}/pkgconfig/libpkgconf.pc

%files m4
%{_datadir}/aclocal/pkg.m4
%{_mandir}/man7/pkg.m4.7*

%files pkg-config
%{_bindir}/pkg-config
%{_bindir}/%{_target_platform}-pkg-config
%{_mandir}/man1/pkg-config.1*
%dir %{_libdir}/pkgconfig
%dir %{_datadir}/pkgconfig

%files -n bomtool
%{_bindir}/bomtool

%changelog
* Fri Aug 16 2024 OpenCloudOS Release Engineering <releng@opencloudos.tech> - 1.9.5-4
- Rebuilt for loongarch release

* Fri Sep 08 2023 OpenCloudOS Release Engineering <releng@opencloudos.tech> - 1.9.5-3
- Rebuilt for OpenCloudOS Stream 23.09

* Fri Aug 25 2023 Wang Guodong <gordonwwang@tencent.com> - 1.9.5-2
- Rebuilt for atf 0.21

* Wed Jul 26 2023 Shuo Wang <abushwang@tencent.com> - 1.9.5-1
- update to 1.9.5

* Fri Apr 28 2023 OpenCloudOS Release Engineering <releng@opencloudos.tech> - 1.8.0-3
- Rebuilt for OpenCloudOS Stream 23.05

* Fri Mar 31 2023 OpenCloudOS Release Engineering <releng@opencloudos.tech> - 1.8.0-2
- Rebuilt for OpenCloudOS Stream 23

* Thu Jun 30 2022 Zhao Zhen <jeremiazhao@tencent.com> - 1.8.0-1
- Initial packaging
